==> kyo-1.0.2.tar.gz: kyo-1.0.2/README.md <==
<div align="center">

# Kyo
  
[![kyo](https://img.shields.io/pypi/v/kyo.svg?style=flat-square)](https://pypi.python.org/pypi/kyo)
[![kyo](https://img.shields.io/pypi/pyversions/kyo.svg?style=flat-square)](https://pypi.python.org/pypi/kyo)

# Questions :tada: 
</div>

### What does kyo mean?

Kyo is a library (from the enhancement of [amino.py](https://github.com/Slimakoi/Amino.py)) focused on the development of bots for the [AminoApps](https://aminoapps.com/) platform, so we can refer to Kyō as secret.


### What are kyo's objectives and approach?

We start from the fact that there are too many junk code repositories regarding the making of bots thanks to bad code made by users who wanted to misuse the AminoApps api so this time we will moderate in kyo a better way to bring such bots without affecting the platform, besides this we want to imply that we will try to bring a quality library out of the wrong hands by bad intentioned users.

In short; **kyo wants to give the platform an air of quality**.

### Contact:

To keep it simple and to keep people confident with the bot we will not communicate via discord so if you want to contact me you are free to do so via my email: **standby@sstandby.com**. Please be brief and direct with what you want (I am willing to answer questions and accept improvements to the code).

### Install kyo:

- Linux/MacOS

```sh
pip install -U kyo
```

- Windows

```sh
py -3 -m pip install -U kyo
```


## License

This work is published under [MIT](https://github.com/cotes2020/jekyll-theme-chirpy/blob/master/LICENSE) License.

==> kyo-1.1.1.tar.gz: kyo-1.1.1/README.md <==
<div align="center">

# Kyo

[![kyo](https://img.shields.io/pypi/v/kyo.svg?style=flat-square)](https://pypi.python.org/pypi/kyo)
[![kyo](https://img.shields.io/pypi/pyversions/kyo.svg?style=flat-square)](https://pypi.python.org/pypi/kyo)

# Questions :tada:
</div>

### What does kyo mean?

Kyo is a library focused on the development of bots for the [AminoApps](https://aminoapps.com/) platform, so we can refer to Kyō as secret.

### What are kyo's objectives and approach?

We start from the fact that there are too many junk code repositories regarding the making of bots thanks to bad code made by users who wanted to misuse the AminoApps api so this time we will moderate in kyo a better way to bring such bots without affecting the platform, besides this we want to imply that we will try to bring a quality library out of the wrong hands by bad intentioned users.

In short; **kyo wants to give the platform an air of quality**.

### Contact:

To keep it simple and to keep people confident with the bot we will not communicate via discord so if you want to contact me you are free to do so via my email: **standby@sstandby.com**. Please be brief and direct with what you want (I am willing to answer questions and accept improvements to the code).

### Install kyo:

- Linux/MacOS

```sh
pip install -U kyo
```

- Windows

```sh
py -3 -m pip install -U kyo
```
### Docs

The api doc will be done through: https://sstandby.com/kyo

## License

This work is published under [MIT](https://github.com/cotes2020/jekyll-theme-chirpy/blob/master/LICENSE) License.
